@@ -1,8 +1,8 @@
 from typing import Optional
 from urllib.parse import urlparse
 
-from django.conf import settings
 from django.core.mail.message import EmailMessage
+from edc_dashboard.utils import get_index_page
 from mempass.password_generator import PasswordGenerator
 
 from .import_users import change_user_template
@@ -21,7 +21,7 @@ def send_new_credentials_to_user(user, nwords: Optional[int] = None) -> EmailMes
     body = change_user_template
     site_names = "\n - ".join([s.name for s in user.userprofile.sites.all()])
     role_names = "\n - ".join([r.display_name for r in user.userprofile.roles.all()])
-    resource_name = urlparse(settings.INDEX_PAGE).netloc
+    resource_name = urlparse(get_index_page()).netloc
     password = change_password(user, nwords)
     opts = {
         "resource_name": resource_name,
